@@ -74,26 +74,35 @@ from flask import current_app, redirect, url_for
 from flask_login import current_user
 from invenio_db import db
 
+from invenio_oauthclient import current_oauthclient
 from invenio_oauthclient.contrib.settings import OAuthSettingsHelper
 from invenio_oauthclient.errors import OAuthResponseError
-from invenio_oauthclient.handlers import authorized_signup_handler, \
-    oauth_error_handler
-from invenio_oauthclient.handlers.rest import \
-    authorized_signup_handler as authorized_signup_rest_handler
-from invenio_oauthclient.handlers.rest import \
-    oauth_resp_remote_error_handler, response_handler
-from invenio_oauthclient.handlers.utils import \
-    require_more_than_one_external_account
+from invenio_oauthclient.handlers import authorized_signup_handler, oauth_error_handler
+from invenio_oauthclient.handlers.rest import (
+    authorized_signup_handler as authorized_signup_rest_handler,
+)
+from invenio_oauthclient.handlers.rest import (
+    oauth_resp_remote_error_handler,
+    response_handler,
+)
+from invenio_oauthclient.handlers.utils import require_more_than_one_external_account
 from invenio_oauthclient.models import RemoteAccount
-from invenio_oauthclient.utils import oauth_link_external_id, \
-    oauth_unlink_external_id
+from invenio_oauthclient.utils import oauth_link_external_id, oauth_unlink_external_id
 
 
 class GitHubOAuthSettingsHelper(OAuthSettingsHelper):
     """Default configuration for GitHub OAuth provider."""
 
-    def __init__(self, title=None, description=None, base_url=None,
-                 app_key=None, icon=None, precedence_mask=None):
+    def __init__(
+        self,
+        title=None,
+        description=None,
+        base_url=None,
+        app_key=None,
+        icon=None,
+        precedence_mask=None,
+        signup_options=None,
+    ):
         """Constructor."""
         super().__init__(
             title or "GitHub",
@@ -105,41 +114,46 @@ class GitHubOAuthSettingsHelper(OAuthSettingsHelper):
             access_token_url="https://github.com/login/oauth/access_token",
             authorize_url="https://github.com/login/oauth/authorize",
             precedence_mask=precedence_mask,
+            signup_options=signup_options,
+        )
+
+        self._handlers = dict(
+            authorized_handler="invenio_oauthclient.handlers:authorized_signup_handler",
+            disconnect_handler="invenio_oauthclient.contrib.github:disconnect_handler",
+            signup_handler=dict(
+                info="invenio_oauthclient.contrib.github:account_info",
+                info_serializer="invenio_oauthclient.contrib.github:account_info_serializer",
+                setup="invenio_oauthclient.contrib.github:account_setup",
+                view="invenio_oauthclient.handlers:signup_handler",
+            ),
+        )
+
+        self._rest_handlers = dict(
+            authorized_handler="invenio_oauthclient.handlers.rest"
+            ":authorized_signup_handler",
+            disconnect_handler="invenio_oauthclient.contrib.github"
+            ":disconnect_rest_handler",
+            signup_handler=dict(
+                info="invenio_oauthclient.contrib.github:account_info",
+                info_serializer="invenio_oauthclient.contrib.github:account_info_serializer",
+                setup="invenio_oauthclient.contrib.github:account_setup",
+                view="invenio_oauthclient.handlers.rest:signup_handler",
+            ),
+            response_handler="invenio_oauthclient.handlers.rest"
+            ":default_remote_response_handler",
+            authorized_redirect_url="/",
+            disconnect_redirect_url="/",
+            signup_redirect_url="/",
+            error_redirect_url="/",
         )
 
     def get_handlers(self):
         """Return GitHub auth handlers."""
-        return dict(
-            authorized_handler='invenio_oauthclient.handlers'
-                               ':authorized_signup_handler',
-            disconnect_handler='invenio_oauthclient.contrib.github'
-                               ':disconnect_handler',
-            signup_handler=dict(
-                info='invenio_oauthclient.contrib.github:account_info',
-                setup='invenio_oauthclient.contrib.github:account_setup',
-                view='invenio_oauthclient.handlers:signup_handler',
-            )
-        )
+        return self._handlers
 
     def get_rest_handlers(self):
         """Return GitHub auth REST handlers."""
-        return dict(
-            authorized_handler='invenio_oauthclient.handlers.rest'
-                               ':authorized_signup_handler',
-            disconnect_handler='invenio_oauthclient.contrib.github'
-                               ':disconnect_rest_handler',
-            signup_handler=dict(
-                info='invenio_oauthclient.contrib.github:account_info',
-                setup='invenio_oauthclient.contrib.github:account_setup',
-                view='invenio_oauthclient.handlers.rest:signup_handler',
-            ),
-            response_handler='invenio_oauthclient.handlers.rest'
-                             ':default_remote_response_handler',
-            authorized_redirect_url='/',
-            disconnect_redirect_url='/',
-            signup_redirect_url='/',
-            error_redirect_url='/'
-        )
+        return self._rest_handlers
 
 
 _github_app = GitHubOAuthSettingsHelper()
@@ -151,10 +165,31 @@ REMOTE_REST_APP = _github_app.remote_rest_app
 """GitHub remote rest application configuration."""
 
 
-def _extract_email(gh):
-    """Get user email from github."""
-    return next(
-        (x.email for x in gh.emails() if x.verified and x.primary), None)
+def _extract_email(emails):
+    """Get user email from GitHub."""
+    return next((x.email for x in emails if x.verified and x.primary), None)
+
+
+def account_info_serializer(remote, resp, user_info, emails_info, **kwargs):
+    """Serialize the account info response object.
+
+    :param remote: The remote application.
+    :param resp: The response of the `authorized` endpoint.
+    :param user_info: The response of the `me` endpoint.
+    :param emails_info: The response of the `emails` endpoint.
+    :returns: A dictionary with serialized user information.
+    """
+    return dict(
+        user=dict(
+            email=_extract_email(emails_info),
+            profile=dict(
+                username=user_info.login,
+                full_name=user_info.name,
+            ),
+        ),
+        external_id=str(user_info.id),
+        external_method=remote.name,
+    )
 
 
 def account_info(remote, resp):
@@ -181,22 +216,16 @@ def account_info(remote, resp):
     the user profile.
 
     :param remote: The remote application.
-    :param resp: The response.
+    :param resp: The response of the `authorized` endpoint.
     :returns: A dictionary with the user information.
     """
-    gh = github3.login(token=resp['access_token'])
-    me = gh.me()
-    return dict(
-        user=dict(
-            email=_extract_email(gh),
-            profile=dict(
-                username=me.login,
-                full_name=me.name,
-            ),
-        ),
-        external_id=str(me.id),
-        external_method='github'
-    )
+    github_obj = github3.login(token=resp["access_token"])
+    user_info = github_obj.me()
+    emails_info = github_obj.emails()
+
+    handlers = current_oauthclient.signup_handlers[remote.name]
+    # `remote` param automatically injected via `make_handler` helper
+    return handlers["info_serializer"](resp, user_info, emails_info=emails_info)
 
 
 def account_setup(remote, token, resp):
@@ -206,17 +235,15 @@ def account_setup(remote, token, resp):
     :param token: The token value.
     :param resp: The response.
     """
-    gh = github3.login(token=resp['access_token'])
+    gh = github3.login(token=resp["access_token"])
     with db.session.begin_nested():
         me = gh.me()
 
-        token.remote_account.extra_data = {'login': me.login, 'id': me.id}
+        token.remote_account.extra_data = {"login": me.login, "id": me.id}
 
         # Create user <-> external id link.
         oauth_link_external_id(
-            token.remote_account.user, dict(
-                id=str(me.id),
-                method='github')
+            token.remote_account.user, dict(id=str(me.id), method=remote.name)
         )
 
 
@@ -227,16 +254,14 @@ def authorized(resp, remote):
     :param resp: The response.
     :param remote: The remote application.
     """
-    if resp and 'error' in resp:
-        if resp['error'] == 'bad_verification_code':
+    if resp and "error" in resp:
+        if resp["error"] == "bad_verification_code":
             # See https://developer.github.com/v3/oauth/#bad-verification-code
             # which recommends starting auth flow again.
-            return redirect(url_for('invenio_oauthclient.login',
-                                    remote_app='github'))
-        elif resp['error'] in ['incorrect_client_credentials',
-                               'redirect_uri_mismatch']:
+            return redirect(url_for("invenio_oauthclient.login", remote_app="github"))
+        elif resp["error"] in ["incorrect_client_credentials", "redirect_uri_mismatch"]:
             raise OAuthResponseError(
-                'Application mis-configuration in GitHub', remote, resp
+                "Application mis-configuration in GitHub", remote, resp
             )
 
     return authorized_signup_handler(resp, remote)
@@ -249,16 +274,16 @@ def authorized_rest(resp, remote):
     :param resp: The response.
     :param remote: The remote application.
     """
-    if resp and 'error' in resp:
-        if resp['error'] == 'bad_verification_code':
+    if resp and "error" in resp:
+        if resp["error"] == "bad_verification_code":
             # See https://developer.github.com/v3/oauth/#bad-verification-code
             # which recommends starting auth flow again.
-            return redirect(url_for('invenio_oauthclient.rest_login',
-                                    remote_app='github'))
-        elif resp['error'] in ['incorrect_client_credentials',
-                               'redirect_uri_mismatch']:
+            return redirect(
+                url_for("invenio_oauthclient.rest_login", remote_app="github")
+            )
+        elif resp["error"] in ["incorrect_client_credentials", "redirect_uri_mismatch"]:
             raise OAuthResponseError(
-                'Application mis-configuration in GitHub', remote, resp
+                "Application mis-configuration in GitHub", remote, resp
             )
 
     return authorized_signup_rest_handler(resp, remote)
@@ -274,15 +299,15 @@ def _disconnect(remote, *args, **kwargs):
     if not current_user.is_authenticated:
         return current_app.login_manager.unauthorized()
 
-    remote_account = RemoteAccount.get(user_id=current_user.get_id(),
-                                       client_id=remote.consumer_key)
-    external_method = 'github'
-    external_ids = [i.id for i in current_user.external_identifiers
-                    if i.method == external_method]
+    remote_account = RemoteAccount.get(
+        user_id=current_user.get_id(), client_id=remote.consumer_key
+    )
+    external_ids = [
+        i.id for i in current_user.external_identifiers if i.method == remote.name
+    ]
 
     if external_ids:
-        oauth_unlink_external_id(dict(id=external_ids[0],
-                                      method=external_method))
+        oauth_unlink_external_id(dict(id=external_ids[0], method=remote.name))
     if remote_account:
         with db.session.begin_nested():
             remote_account.delete()
@@ -295,7 +320,7 @@ def disconnect_handler(remote, *args, **kwargs):
     :returns: The HTML response.
     """
     _disconnect(remote, *args, **kwargs)
-    return redirect(url_for('invenio_oauthclient_settings.index'))
+    return redirect(url_for("invenio_oauthclient_settings.index"))
 
 
 def disconnect_rest_handler(remote, *args, **kwargs):
@@ -305,6 +330,7 @@ def disconnect_rest_handler(remote, *args, **kwargs):
     :returns: The HTML response.
     """
     _disconnect(remote, *args, **kwargs)
-    redirect_url = current_app.config['OAUTHCLIENT_REST_REMOTE_APPS'][
-        remote.name]['disconnect_redirect_url']
+    redirect_url = current_app.config["OAUTHCLIENT_REST_REMOTE_APPS"][remote.name][
+        "disconnect_redirect_url"
+    ]
     return response_handler(remote, redirect_url)
