@@ -36,39 +36,54 @@ from flask import current_app, redirect, url_for
 from flask_login import current_user
 from invenio_db import db
 
+from invenio_oauthclient import current_oauthclient
 from invenio_oauthclient.handlers.rest import response_handler
-from invenio_oauthclient.handlers.utils import \
-    require_more_than_one_external_account
+from invenio_oauthclient.handlers.utils import require_more_than_one_external_account
 from invenio_oauthclient.models import RemoteAccount
-from invenio_oauthclient.utils import oauth_link_external_id, \
-    oauth_unlink_external_id
+from invenio_oauthclient.utils import oauth_link_external_id, oauth_unlink_external_id
 
 from .helpers import get_user_info
 
 
-def info_handler(remote, resp):
-    """Retrieve remote account information for finding matching local users."""
-    user_info = get_user_info(remote, resp)
+def info_serializer_handler(remote, resp, user_info, **kwargs):
+    """Serialize the account info response object.
 
+    :param remote: The remote application.
+    :param resp: The response of the `authorized` endpoint.
+    :param user_info: The response of the `user info` endpoint.
+    :returns: A dictionary with serialized user information.
+    """
     # fill out the information required by
     # 'invenio-accounts' and 'invenio-userprofiles'.
     #
     # note: "external_id": `preferred_username` should also work,
     #       as it is seemingly not editable in Keycloak
-    result = {
+    return {
         "user": {
             "active": True,
             "email": user_info["email"],
             "profile": {
                 "full_name": user_info.get("name"),
                 "username": user_info.get("preferred_username"),
-            }
+            },
         },
         "external_id": user_info["sub"],
         "external_method": remote.name,
     }
 
-    return result
+
+def info_handler(remote, resp):
+    """Retrieve remote account information for finding matching local users.
+
+    :param remote: The remote application.
+    :param resp: The response of the `authorized` endpoint.
+    :returns: A dictionary with the user information.
+    """
+    user_info = get_user_info(remote, resp)
+
+    handlers = current_oauthclient.signup_handlers[remote.name]
+    # `remote` param automatically injected via `make_handler` helper
+    return handlers["info_serializer"](resp, user_info)
 
 
 def setup_handler(remote, token, resp):
@@ -83,10 +98,7 @@ def setup_handler(remote, token, resp):
         }
 
         user = token.remote_account.user
-        external_id = {
-            "id": keycloak_id,
-            "method": remote.name
-        }
+        external_id = {"id": keycloak_id, "method": remote.name}
 
         # link account with external Keycloak ID
         oauth_link_external_id(user, external_id)
@@ -98,16 +110,14 @@ def _disconnect(remote, *args, **kwargs):
     if not current_user.is_authenticated:
         return current_app.login_manager.unauthorized()
 
-    account = RemoteAccount.get(user_id=current_user.get_id(),
-                                client_id=remote.consumer_key)
+    account = RemoteAccount.get(
+        user_id=current_user.get_id(), client_id=remote.consumer_key
+    )
 
     keycloak_id = account.extra_data.get("keycloak_id")
 
     if keycloak_id:
-        external_id = {
-            "id": keycloak_id,
-            "method": remote.name
-        }
+        external_id = {"id": keycloak_id, "method": remote.name}
 
         oauth_unlink_external_id(external_id)
 
@@ -119,7 +129,7 @@ def _disconnect(remote, *args, **kwargs):
 def disconnect_handler(remote, *args, **kwargs):
     """Handle unlinking of the remote account."""
     _disconnect(remote, *args, **kwargs)
-    return redirect(url_for('invenio_oauthclient_settings.index'))
+    return redirect(url_for("invenio_oauthclient_settings.index"))
 
 
 def disconnect_rest_handler(remote, *args, **kwargs):
