@@ -75,74 +75,86 @@ from flask import current_app, redirect, url_for
 from flask_login import current_user
 from invenio_db import db
 
+from invenio_oauthclient import current_oauthclient
 from invenio_oauthclient.contrib.settings import OAuthSettingsHelper
 from invenio_oauthclient.handlers.rest import response_handler
-from invenio_oauthclient.handlers.utils import \
-    require_more_than_one_external_account
+from invenio_oauthclient.handlers.utils import require_more_than_one_external_account
 from invenio_oauthclient.models import RemoteAccount
-from invenio_oauthclient.utils import oauth_link_external_id, \
-    oauth_unlink_external_id
+from invenio_oauthclient.utils import oauth_link_external_id, oauth_unlink_external_id
 
 
 class ORCIDOAuthSettingsHelper(OAuthSettingsHelper):
     """Default configuration for ORCID OAuth provider."""
 
-    def __init__(self, title=None, description=None, base_url=None,
-                 app_key=None, access_token_url=None, authorize_url=None,
-                 precedence_mask=None):
+    def __init__(
+        self,
+        title=None,
+        description=None,
+        base_url=None,
+        app_key=None,
+        access_token_url=None,
+        authorize_url=None,
+        precedence_mask=None,
+        signup_options=None,
+    ):
         """Constructor."""
         access_token_url = access_token_url or "https://orcid.org/oauth/token"
         authorize_url = authorize_url or "https://orcid.org/oauth/authorize"
         precedence_mask = precedence_mask or {
             "email": False,
         }
+        signup_options = signup_options or {
+            "auto_confirm": False,
+            "send_register_msg": True,
+        }
 
         super().__init__(
             title or "ORCID",
             description or "Connecting Research and Researchers.",
             base_url or "https://pub.orcid.org/v1.2/",
             app_key or "ORCID_APP_CREDENTIALS",
-            request_token_params={"scope": "/authenticate",
-                                  "show_login": "true"},
+            request_token_params={"scope": "/authenticate", "show_login": "true"},
             access_token_url=access_token_url,
             authorize_url=authorize_url,
             content_type="application/json",
             precedence_mask=precedence_mask,
+            signup_options=signup_options,
+        )
+
+        self._handlers = dict(
+            authorized_handler="invenio_oauthclient.handlers:authorized_signup_handler",
+            disconnect_handler="invenio_oauthclient.contrib.orcid:disconnect_handler",
+            signup_handler=dict(
+                info="invenio_oauthclient.contrib.orcid:account_info",
+                info_serializer="invenio_oauthclient.contrib.orcid:account_info_serializer",
+                setup="invenio_oauthclient.contrib.orcid:account_setup",
+                view="invenio_oauthclient.handlers:signup_handler",
+            ),
+        )
+
+        self._rest_handlers = dict(
+            authorized_handler="invenio_oauthclient.handlers.rest:authorized_signup_handler",
+            disconnect_handler="invenio_oauthclient.contrib.orcid:disconnect_rest_handler",
+            signup_handler=dict(
+                info="invenio_oauthclient.contrib.orcid:account_info",
+                info_serializer="invenio_oauthclient.contrib.orcid:account_info_serializer",
+                setup="invenio_oauthclient.contrib.orcid:account_setup",
+                view="invenio_oauthclient.handlers.rest:signup_handler",
+            ),
+            response_handler="invenio_oauthclient.handlers.rest:default_remote_response_handler",
+            authorized_redirect_url="/",
+            disconnect_redirect_url="/",
+            signup_redirect_url="/",
+            error_redirect_url="/",
         )
 
     def get_handlers(self):
         """Return ORCID auth handlers."""
-        return dict(
-            authorized_handler='invenio_oauthclient.handlers'
-                               ':authorized_signup_handler',
-            disconnect_handler='invenio_oauthclient.contrib.orcid'
-                               ':disconnect_handler',
-            signup_handler=dict(
-                info='invenio_oauthclient.contrib.orcid:account_info',
-                setup='invenio_oauthclient.contrib.orcid:account_setup',
-                view='invenio_oauthclient.handlers:signup_handler',
-            )
-        )
+        return self._handlers
 
     def get_rest_handlers(self):
         """Return ORCID auth REST handlers."""
-        return dict(
-            authorized_handler='invenio_oauthclient.handlers.rest'
-                               ':authorized_signup_handler',
-            disconnect_handler='invenio_oauthclient.contrib.orcid'
-                               ':disconnect_rest_handler',
-            signup_handler=dict(
-                info='invenio_oauthclient.contrib.orcid:account_info',
-                setup='invenio_oauthclient.contrib.orcid:account_setup',
-                view='invenio_oauthclient.handlers.rest:signup_handler',
-            ),
-            response_handler='invenio_oauthclient.handlers.rest'
-                             ':default_remote_response_handler',
-            authorized_redirect_url='/',
-            disconnect_redirect_url='/',
-            signup_redirect_url='/',
-            error_redirect_url='/'
-        )
+        return self._rest_handlers
 
 
 _orcid_app = ORCIDOAuthSettingsHelper()
@@ -155,8 +167,7 @@ REMOTE_REST_APP = _orcid_app.remote_rest_app
 """ORCID Remote REST Application."""
 
 _orcid_member_app = ORCIDOAuthSettingsHelper(
-    base_url='https://api.orcid.org/',
-    access_token_url='https://orcid.org/oauth/token'
+    base_url="https://api.orcid.org/", access_token_url="https://orcid.org/oauth/token"
 )
 REMOTE_MEMBER_APP = _orcid_member_app.remote_app
 """ORCID Remote Application with member API."""
@@ -165,9 +176,9 @@ REMOTE_MEMBER_APP = _orcid_member_app.remote_app
 # SANDBOX
 
 _orcid_sandbox_app = ORCIDOAuthSettingsHelper(
-    base_url='https://pub.sandbox.orcid.org/',
-    access_token_url='https://sandbox.orcid.org/oauth/token',
-    authorize_url='https://sandbox.orcid.org/oauth/authorize#show_login',
+    base_url="https://pub.sandbox.orcid.org/",
+    access_token_url="https://sandbox.orcid.org/oauth/token",
+    authorize_url="https://sandbox.orcid.org/oauth/authorize#show_login",
 )
 REMOTE_SANDBOX_APP = _orcid_sandbox_app.remote_app
 """ORCID Sandbox Remote Application with public API."""
@@ -176,14 +187,32 @@ REMOTE_SANDBOX_REST_APP = _orcid_sandbox_app.remote_rest_app
 """ORCID Sandbox Remote Application with public API."""
 
 _orcid_sandbox_member_app = ORCIDOAuthSettingsHelper(
-    base_url='https://api.sandbox.orcid.org/',
-    access_token_url='https://sandbox.orcid.org/oauth/token',
-    authorize_url='https://sandbox.orcid.org/oauth/authorize#show_login',
+    base_url="https://api.sandbox.orcid.org/",
+    access_token_url="https://sandbox.orcid.org/oauth/token",
+    authorize_url="https://sandbox.orcid.org/oauth/authorize#show_login",
 )
 REMOTE_SANDBOX_MEMBER_APP = _orcid_sandbox_member_app.remote_app
 """ORCID sandbox member API."""
 
 
+def account_info_serializer(remote, resp, **kwargs):
+    """Serialize the account info response object.
+
+    :param remote: The remote application.
+    :param resp: The response of the `authorized` endpoint.
+    :returns: A dictionary with serialized user information.
+    """
+    return {
+        "external_id": resp.get("orcid"),
+        "external_method": remote.name,
+        "user": {
+            "profile": {
+                "full_name": resp.get("name"),
+            },
+        },
+    }
+
+
 def account_info(remote, resp):
     """Retrieve remote account information used to find local user.
 
@@ -197,25 +226,17 @@ def account_info(remote, resp):
                     'full_name': 'Full Name',
                 },
             },
-            'external_id': 'github-unique-identifier',
-            'external_method': 'github',
+            'external_id': 'orcid-unique-identifier',
+            'external_method': 'orcid',
         }
 
     :param remote: The remote application.
-    :param resp: The response.
+    :param resp: The response of the `authorized` endpoint.
     :returns: A dictionary with the user information.
     """
-    orcid = resp.get('orcid')
-
-    return {
-        'external_id': orcid,
-        'external_method': 'orcid',
-        'user': {
-            'profile': {
-                'full_name': resp.get('name'),
-            },
-        },
-    }
+    handlers = current_oauthclient.signup_handlers[remote.name]
+    # `remote` param automatically injected via `make_handler` helper
+    return handlers["info_serializer"](resp)
 
 
 @require_more_than_one_external_account
@@ -227,12 +248,13 @@ def _disconnect(remote, *args, **kwargs):
     if not current_user.is_authenticated:
         return current_app.login_manager.unauthorized()
 
-    account = RemoteAccount.get(user_id=current_user.get_id(),
-                                client_id=remote.consumer_key)
-    orcid = account.extra_data.get('orcid')
+    account = RemoteAccount.get(
+        user_id=current_user.get_id(), client_id=remote.consumer_key
+    )
+    orcid = account.extra_data.get("orcid")
 
     if orcid:
-        oauth_unlink_external_id({'id': orcid, 'method': 'orcid'})
+        oauth_unlink_external_id({"id": orcid, "method": "orcid"})
     if account:
         with db.session.begin_nested():
             account.delete()
@@ -244,7 +266,7 @@ def disconnect_handler(remote, *args, **kwargs):
     :param remote: The remote application.
     """
     _disconnect(remote, *args, **kwargs)
-    return redirect(url_for('invenio_oauthclient_settings.index'))
+    return redirect(url_for("invenio_oauthclient_settings.index"))
 
 
 def disconnect_rest_handler(remote, *args, **kwargs):
@@ -253,8 +275,9 @@ def disconnect_rest_handler(remote, *args, **kwargs):
     :param remote: The remote application.
     """
     _disconnect(remote, *args, **kwargs)
-    redirect_url = current_app.config['OAUTHCLIENT_REST_REMOTE_APPS'][
-        remote.name]['disconnect_redirect_url']
+    redirect_url = current_app.config["OAUTHCLIENT_REST_REMOTE_APPS"][remote.name][
+        "disconnect_redirect_url"
+    ]
     return response_handler(remote, redirect_url)
 
 
@@ -267,16 +290,16 @@ def account_setup(remote, token, resp):
     """
     with db.session.begin_nested():
         # Retrieve ORCID from response.
-        orcid = resp.get('orcid')
-        full_name = resp.get('name')
+        orcid = resp.get("orcid")
+        full_name = resp.get("name")
 
         # Set ORCID in extra_data.
         token.remote_account.extra_data = {
-            'orcid': orcid,
-            'full_name': full_name,
+            "orcid": orcid,
+            "full_name": full_name,
         }
 
         user = token.remote_account.user
 
         # Create user <-> external id link.
-        oauth_link_external_id(user, {'id': orcid, 'method': 'orcid'})
+        oauth_link_external_id(user, {"id": orcid, "method": "orcid"})
