@@ -18,8 +18,10 @@ from invenio_accounts.models import User
 from invenio_db import db
 from six.moves.urllib_parse import parse_qs, urlparse
 
-from invenio_oauthclient.contrib.keycloak.helpers import _format_public_key, \
-    get_user_info
+from invenio_oauthclient.contrib.keycloak.helpers import (
+    _format_public_key,
+    get_user_info,
+)
 from invenio_oauthclient.errors import OAuthError
 from invenio_oauthclient.models import UserIdentity
 
@@ -36,11 +38,7 @@ def test_login(app):
     client = app.test_client()
 
     resp = client.get(
-        url_for(
-            "invenio_oauthclient.login",
-            remote_app="keycloak",
-            next="/someurl/"
-        )
+        url_for("invenio_oauthclient.login", remote_app="keycloak", next="/someurl/")
     )
 
     assert resp.status_code == 302
@@ -58,61 +56,61 @@ def test_login(app):
 
 
 @httpretty.activate
-def test_authorized_signup_valid_user(app_with_userprofiles,
-                                      example_keycloak_token,
-                                      example_keycloak_userinfo,
-                                      example_keycloak_realm_info):
+def test_authorized_signup_valid_user(
+    app_with_userprofiles,
+    example_keycloak_token,
+    example_keycloak_userinfo,
+    example_keycloak_realm_info,
+):
     """Test authorized callback with sign-up."""
     app = app_with_userprofiles
     example_keycloak = example_keycloak_userinfo.data
 
     with app.test_client() as c:
         # ensure that remote_apps have been initialized (before first request)
-        resp = c.get(
-            url_for("invenio_oauthclient.login", remote_app="keycloak")
-        )
+        resp = c.get(url_for("invenio_oauthclient.login", remote_app="keycloak"))
         assert resp.status_code == 302
 
         # mock a running keycloak instance
-        mock_keycloak(app.config,
-                      example_keycloak_token,
-                      example_keycloak,
-                      example_keycloak_realm_info)
+        mock_keycloak(
+            app.config,
+            example_keycloak_token,
+            example_keycloak,
+            example_keycloak_realm_info,
+        )
 
         # user authorized the request and is redirected back
         resp = c.get(
             url_for(
-                "invenio_oauthclient.authorized", remote_app="keycloak",
-                code="test", state=get_state("keycloak")
+                "invenio_oauthclient.authorized",
+                remote_app="keycloak",
+                code="test",
+                state=get_state("keycloak"),
             )
         )
 
         # note: because we provided an e-mail address in 'info_handler',
         #       the user does not need to sign up
         assert resp.status_code == 302
-        assert resp.location == ("http://localhost/"
-                                 "account/settings/linkedaccounts/")
+        assert resp.location == "/account/settings/linkedaccounts/"
 
         # check that the user exists
         user = User.query.filter_by(email=example_keycloak["email"]).one()
         assert user is not None
         assert user.email == example_keycloak["email"]
-        assert user.profile.full_name == "Max Moser"
+        assert user.user_profile["full_name"] == "Max Moser"
         assert user.active
+        assert user.confirmed_at
 
         # check that the user has a linked Keycloak account
         uid = UserIdentity.query.filter_by(
-            method="keycloak",
-            id_user=user.id,
-            id=example_keycloak["sub"]
+            method="keycloak", id_user=user.id, id=example_keycloak["sub"]
         ).one()
         assert uid.user is user
 
         # try to disconnect the Keycloak account again
         # which shouldn't work, because it's the user's only means of login
-        resp = c.get(
-            url_for("invenio_oauthclient.disconnect", remote_app="keycloak")
-        )
+        resp = c.get(url_for("invenio_oauthclient.disconnect", remote_app="keycloak"))
 
         assert resp.status_code == 400
 
@@ -122,9 +120,7 @@ def test_authorized_signup_valid_user(app_with_userprofiles,
 
         # check that the Keycloak account hasn't been unlinked
         count = UserIdentity.query.filter_by(
-            method="keycloak",
-            id_user=user.id,
-            id=example_keycloak["sub"]
+            method="keycloak", id_user=user.id, id=example_keycloak["sub"]
         ).count()
         assert count == 1
 
@@ -133,9 +129,7 @@ def test_authorized_signup_valid_user(app_with_userprofiles,
         db.session.commit()
 
         # try to disconnect the Keycloak account again
-        resp = c.get(
-            url_for("invenio_oauthclient.disconnect", remote_app="keycloak")
-        )
+        resp = c.get(url_for("invenio_oauthclient.disconnect", remote_app="keycloak"))
 
         assert resp.status_code == 302
 
@@ -145,13 +139,64 @@ def test_authorized_signup_valid_user(app_with_userprofiles,
 
         # check that the Keycloak account hasn't been unlinked
         count = UserIdentity.query.filter_by(
-            method="keycloak",
-            id_user=user.id,
-            id=example_keycloak["sub"]
+            method="keycloak", id_user=user.id, id=example_keycloak["sub"]
         ).count()
         assert count == 0
 
 
+@httpretty.activate
+def test_authorized_signup_valid_user_not_confirmed(
+    app_with_userprofiles,
+    example_keycloak_token,
+    example_keycloak_userinfo,
+    example_keycloak_realm_info,
+):
+    """Test authorized callback with sign-up and user confirmed."""
+    app = app_with_userprofiles
+    example_keycloak = example_keycloak_userinfo.data
+
+    # change default settings to avoid auto-confirm user
+    keycloak_app = app.config["OAUTHCLIENT_REMOTE_APPS"]["keycloak"]
+    keycloak_app["signup_options"]["auto_confirm"] = False
+    keycloak_app["signup_options"]["send_register_msg"] = True
+
+    with app.test_client() as c:
+        # ensure that remote_apps have been initialized (before first request)
+        resp = c.get(url_for("invenio_oauthclient.login", remote_app="keycloak"))
+        assert resp.status_code == 302
+
+        # mock a running keycloak instance
+        mock_keycloak(
+            app.config,
+            example_keycloak_token,
+            example_keycloak,
+            example_keycloak_realm_info,
+        )
+
+        # user authorized the request and is redirected back
+        resp = c.get(
+            url_for(
+                "invenio_oauthclient.authorized",
+                remote_app="keycloak",
+                code="test",
+                state=get_state("keycloak"),
+            )
+        )
+
+        # note: because we provided an e-mail address in 'info_handler',
+        #       the user does not need to sign up
+        assert resp.status_code == 302
+        assert resp.location == "/account/settings/linkedaccounts/"
+
+        # check that the user has been created and confirmed
+        user = User.query.filter_by(email=example_keycloak["email"]).one()
+        assert user is not None
+        assert user.email == example_keycloak["email"]
+        assert user.user_profile["full_name"] == "Max Moser"
+        assert user.active
+        assert not user.confirmed_at
+
+
 def test_authorized_reject(app, example_keycloak_token):
     """Test a rejected request."""
     with app.test_client() as c:
@@ -159,25 +204,28 @@ def test_authorized_reject(app, example_keycloak_token):
 
         resp = c.get(
             url_for(
-                "invenio_oauthclient.authorized", remote_app="keycloak",
-                error="access_denied", error_description="User denied access",
-                state=get_state("keycloak")
+                "invenio_oauthclient.authorized",
+                remote_app="keycloak",
+                error="access_denied",
+                error_description="User denied access",
+                state=get_state("keycloak"),
             )
         )
-
         assert resp.status_code in (301, 302)
-        assert resp.location == "http://localhost/"
+        assert resp.location == "/"
 
         # check message flash
         assert session["_flashes"][0][0] == "info"
 
 
 @httpretty.activate
-def test_authorized_already_authenticated(app,
-                                          models_fixture,
-                                          example_keycloak_token,
-                                          example_keycloak_userinfo,
-                                          example_keycloak_realm_info):
+def test_authorized_already_authenticated(
+    app,
+    models_fixture,
+    example_keycloak_token,
+    example_keycloak_userinfo,
+    example_keycloak_realm_info,
+):
     """Test authorized callback with sign-in."""
     datastore = app.extensions["invenio-accounts"].datastore
     login_manager = app.login_manager
@@ -202,15 +250,18 @@ def test_authorized_already_authenticated(app,
         c.get(url_for("invenio_oauthclient.login", remote_app="keycloak"))
 
         # mock a running keycloak instance
-        mock_keycloak(app.config,
-                      example_keycloak_token,
-                      example_keycloak,
-                      example_keycloak_realm_info)
+        mock_keycloak(
+            app.config,
+            example_keycloak_token,
+            example_keycloak,
+            example_keycloak_realm_info,
+        )
 
         # user goes to 'linked accounts' and clicks 'connect' with Keycloak
         resp = c.get(
-            url_for("invenio_oauthclient.login", remote_app="keycloak",
-                    next="/someurl/")
+            url_for(
+                "invenio_oauthclient.login", remote_app="keycloak", next="/someurl/"
+            )
         )
 
         assert resp.status_code == 302
@@ -218,32 +269,28 @@ def test_authorized_already_authenticated(app,
         # the user logged in to Keycloak and authorized the request
         resp = c.get(
             url_for(
-                "invenio_oauthclient.authorized", remote_app="keycloak",
-                code="test", state=get_state("keycloak")
+                "invenio_oauthclient.authorized",
+                remote_app="keycloak",
+                code="test",
+                state=get_state("keycloak"),
             )
         )
 
         # check if the Keycloak account has been linked to the user
         u = User.query.filter_by(email=existing_mail).one()
         UserIdentity.query.filter_by(
-            method="keycloak",
-            id_user=u.id,
-            id=example_keycloak["sub"]
+            method="keycloak", id_user=u.id, id=example_keycloak["sub"]
         ).one()
 
         # let the user hit the 'disconnect' button
-        resp = c.get(
-            url_for("invenio_oauthclient.disconnect", remote_app="keycloak")
-        )
+        resp = c.get(url_for("invenio_oauthclient.disconnect", remote_app="keycloak"))
         assert resp.status_code == 302
 
         # check that the user still exists,
         # but the Keycloak account has been unlinked
         u = User.query.filter_by(email=existing_mail).one()
         count = UserIdentity.query.filter_by(
-            method="keycloak",
-            id_user=u.id,
-            id=example_keycloak["sub"]
+            method="keycloak", id_user=u.id, id=example_keycloak["sub"]
         ).count()
         assert count == 0
 
@@ -252,11 +299,10 @@ def test_not_authenticated(app):
     """Test disconnect when the user is not authenticated."""
     with app.test_client() as c:
         assert not current_user.is_authenticated
-        resp = c.get(
-            url_for('invenio_oauthclient.disconnect', remote_app='keycloak')
-        )
+        resp = c.get(url_for("invenio_oauthclient.disconnect", remote_app="keycloak"))
         assert resp.status_code == 302
 
+
 # - - - - - - - - - - - - - - - - - - #
 # Tests for Keycloak helper functions #
 # - - - - - - - - - - - - - - - - - - #
@@ -288,27 +334,26 @@ def test_format_public_key_idempotence(example_keycloak_public_key):
 
 
 @httpretty.activate
-def test_get_realm_key(app,
-                       example_keycloak_token,
-                       example_keycloak_userinfo,
-                       example_keycloak_realm_info):
+def test_get_realm_key(
+    app, example_keycloak_token, example_keycloak_userinfo, example_keycloak_realm_info
+):
     """Test the mechanism for fetching the realm's public key."""
-    mock_keycloak(app.config,
-                  example_keycloak_token,
-                  example_keycloak_userinfo.data,
-                  example_keycloak_realm_info)
+    mock_keycloak(
+        app.config,
+        example_keycloak_token,
+        example_keycloak_userinfo.data,
+        example_keycloak_realm_info,
+    )
 
 
 @httpretty.activate
-def test_get_userinfo_from_token(app,
-                                 example_keycloak_token,
-                                 example_keycloak_userinfo,
-                                 example_keycloak_realm_info):
+def test_get_userinfo_from_token(
+    app, example_keycloak_token, example_keycloak_userinfo, example_keycloak_realm_info
+):
     """Test the "id_token" extraction mechanism from Keycloak's response."""
-    mock_keycloak(app.config,
-                  example_keycloak_token,
-                  dict(),
-                  example_keycloak_realm_info)
+    mock_keycloak(
+        app.config, example_keycloak_token, dict(), example_keycloak_realm_info
+    )
 
     token = example_keycloak_token["id_token"]
     options = {"verify_signature": False}
@@ -322,29 +367,35 @@ def test_get_userinfo_from_token(app,
         # the OAuthClient has to get its token from this call
         c.get(
             url_for(
-                "invenio_oauthclient.authorized", remote_app="keycloak",
-                code="test", state=get_state("keycloak")
+                "invenio_oauthclient.authorized",
+                remote_app="keycloak",
+                code="test",
+                state=get_state("keycloak"),
             )
         )
 
-        user_info = get_user_info(remote, example_keycloak_token,
-                                  fallback_to_endpoint=False,
-                                  options={"verify_exp": False})
+        user_info = get_user_info(
+            remote,
+            example_keycloak_token,
+            fallback_to_endpoint=False,
+            options={"verify_exp": False},
+        )
 
         assert user_info is not None
         assert user_info == expected_result
 
 
 @httpretty.activate
-def test_get_userinfo_from_endpoint(app,
-                                    example_keycloak_token,
-                                    example_keycloak_userinfo,
-                                    example_keycloak_realm_info):
+def test_get_userinfo_from_endpoint(
+    app, example_keycloak_token, example_keycloak_userinfo, example_keycloak_realm_info
+):
     """Test the "/userinfo" mechanism when the "id_token" mechanism fails."""
-    mock_keycloak(app.config,
-                  example_keycloak_token,
-                  example_keycloak_userinfo.data,
-                  example_keycloak_realm_info)
+    mock_keycloak(
+        app.config,
+        example_keycloak_token,
+        example_keycloak_userinfo.data,
+        example_keycloak_realm_info,
+    )
 
     with app.test_client() as c:
         # ensure that remote apps have been loaded (before first request)
@@ -355,8 +406,10 @@ def test_get_userinfo_from_endpoint(app,
         # the OAuthClient has to get its token from this call
         c.get(
             url_for(
-                "invenio_oauthclient.authorized", remote_app="keycloak",
-                code="test", state=get_state("keycloak")
+                "invenio_oauthclient.authorized",
+                remote_app="keycloak",
+                code="test",
+                state=get_state("keycloak"),
             )
         )
 
@@ -369,8 +422,10 @@ def test_get_userinfo_from_endpoint(app,
 
 def test_raise_on_invalid_app_name():
     """Test that the app name format is validated."""
+
     class FakeRemote:
         """Fake remote class."""
+
         def __init__(self, name):
             """Constructor."""
             self.name = name
